# Examples

### Document Processing

Load PDFs from S3, extract text, run layout analysis, and compute embeddings

### Audio Transcription with Whisper

Effortlessly convert audio to text at scale

📃

### MinHash Deduplication on Common Crawl

Deduplicate web text at scale with MinHash, LSH, and Connected Components.

📊

### Text Embeddings for Turbopuffer

Generate embeddings on text to store in vector databases

🤖

### LLMs on Hugging Face Datasets

Load Red Pajamas dataset and perform similarity search

🎨

### Generate Images with Stable Diffusion

Using text prompts with deep learning models

🔍

### Query Images

Retrieve the top N "reddest" images from the Open Images dataset

🔢

### MNIST Digit Classification

Run classification with deep learning

📈

### Window Functions

Efficient window functions for ranking, computing deltas, and tracking cumulative sums